/* roadmap_plugin.c - a low level module to manage plugins for RoadMap.
 *
 * LICENSE:
 *
 *   Copyright 2002 Pascal F. Martin
 *
 *   This file is part of RoadMap.
 *
 *   RoadMap is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   RoadMap is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with RoadMap; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * SYNOPSYS:
 *
 *   This module implement the OS calls necessary for installing a plugin
 *   library. Note that there is no way for unloading a plugin library at
 *   that time.
 */

#include <stdio.h>
#include <dlfcn.h>
#include <stdlib.h>

#include "roadmap.h"
#include "roadmap_path.h"
#include "roadmap_library.h"

#include "roadmap_plugin.h"


typedef void (*RoadMapPluginInit) (void);

int roadmap_plugin_load (const char *category, const char *id) {

   const char *path;
   const char *full_name;
   const char *name = roadmap_path_join (category, id);

   RoadMapPluginInit init;


   for (path = roadmap_path_first ();
        path != NULL;
        path = roadmap_path_next(path)) {

      full_name = roadmap_path_join (path, name);

      if (roadmap_library_exists (full_name)) {

         library = roadmap_library_load (full_name);

         if (library != NULL) {

            init = (RoadMapPluginInit)
               roadmap_library_symbol (library, "roadmap_plugin_init");

            if (init != NULL) {

               init ();
               roadmap_path_free (full_name);

               return 1; /* Success. */
            }
            roadmap_log (ROADMAP_ERROR,
                        "library %s is not a RoadMap plugin", full_name);
         }
      }
      roadmap_path_free (full_name);
   }

   roadmap_log (ROADMAP_ERROR, "could not find plugin %s", name);
   return 0;
}

