#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#include "roadmap.h"
#include "roadmap_math.h"
#include "roadmap_square.h"
#include "roadmap_config.h"

#include "roadmap_trigonometry.h"

static int roadmap_math_arccosine (int cosine, int sign) {
    
    int i;
    int low;
    int high;
    int result;
    int cosine_negative = 0;
    
    if (cosine < 0) {
        cosine = 0 - cosine;
        cosine_negative = 1;
    }
    if (cosine >= 32768) {
        if (cosine > 32768) {
            return 0;
        }
        cosine = 32767;
    }
    
    high = 45;
    low  = 0;
    
    if (cosine >= RoadMapTrigonometricTable[45].y) {
        
        while (high > low + 1) {
            
            i = (high + low) / 2;
            
            if (cosine > RoadMapTrigonometricTable[i-1].y) {
                high = i - 1;
            } else if (cosine < RoadMapTrigonometricTable[i].y) {
                low = i;
            } else {
                high = i;
                break;
            }
        }
        
        result = sign * high;
        
    } else {
        
        while (high > low + 1) {
            
            i = (high + low) / 2;
            
            if (cosine >= RoadMapTrigonometricTable[i].x) {
                low = i;
            } else if (cosine < RoadMapTrigonometricTable[i-1].y) {
                high = i - 1;
            } else {
                high = i;
                break;
            }
        }
        
        result = sign * (90 - high);
    }
    
    if (cosine_negative) {
        result = 180 - result;
        if (result > 180) {
            result = result - 360;
        }
    }
    return result;
}

int roadmap_math_azymuth (RoadMapPosition *point1, RoadMapPosition *point2) {

    int result;
    double x;
    double y;
    double d;


    x = (point2->longitude - point1->longitude);
    y = (point2->latitude  - point1->latitude);

    d = sqrt ((x * x) + (y * y));
    
    if (abs(d) > 0.0001) {
        result = roadmap_math_arccosine
                    ((int) ((32768 * y) / d), (x > 0)?1:-1);
    } else {
        result = 0;
    }
    
    return result;
}


void test_azymuth (int longitude, int latitude) {
    
    RoadMapPosition point1 = {0, 0};
    RoadMapPosition point2;
    
    point2.longitude = longitude;
    point2.latitude  = latitude;

    printf ("%4d, %4d -> %2d\n",
            point2.longitude, point2.latitude,
            roadmap_math_azymuth (&point1, &point2));
}

static void roadmap_math_trigonometry (int angle, int *sine_p, int *cosine_p) {

   int i = angle % 90;
   int sine;
   int cosine;

   if (i < 0) {
      i += 90;
   }

   if (i <= 45) {
      sine   = RoadMapTrigonometricTable[i].x;
      cosine = RoadMapTrigonometricTable[i].y;
   } else {
      i = 90 - i;
      sine   = RoadMapTrigonometricTable[i].y;
      cosine = RoadMapTrigonometricTable[i].x;
   }

   i = (angle / 90) % 4;
   if (i < 0) {
      i += 4;
   }

   switch (i) {
   case 0:   *sine_p = sine;       *cosine_p = cosine;     break;
   case 1:   *sine_p = cosine;     *cosine_p = 0 - sine;   break;
   case 2:   *sine_p = 0 - sine;   *cosine_p = 0 - cosine; break;
   case 3:   *sine_p = 0 - cosine; *cosine_p = sine;       break;
   }
}


int main (void) {
    
    int i;
    RoadMapPosition point2;
    
    // for (i = 0; i < 32768; i += 100) {
        // printf ("%6d -> %2d\n", i, roadmap_math_arccosine(i));
    // }
    
    roadmap_math_trigonometry (-170, &i, &i);
    
    test_azymuth (-1000, -3000);
    test_azymuth (-3000, -1000);
    test_azymuth (-1000, -1000);
    test_azymuth (-2000, 0);
    test_azymuth (-1000, 1000);
    test_azymuth (0,     2000);
    test_azymuth (1000,  1000);
    test_azymuth (2000,  0);
    test_azymuth (1000,  -1000);
    test_azymuth (0,     -2000);
    test_azymuth (-1000, -1000);
        
    return 0;
}

